#
# spec file for package 389-ds-base
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?sles_version} == 11
%global with_systemd 0
%else
%global with_systemd 1
%endif

Name:           389-ds-base
Summary:        389 Directory Server
Version:        1.2.11.30
Release:        6.3%{?dist}.kolab_3.4

Group:          Productivity/Networking/LDAP/Servers
License:        GPL-2.0
Url:            http://port389.org/
#DL-URL:        http://port389.org/wiki/Source
#Git-Clone:     git://git.fedorahosted.org/389/ds
Source:         http://port389.org/sources/%{name}-%{version}.tar.bz2
# Patch1: Make init scripts LSB conform
Patch1:         389-ds-base-1.2.11.15_dirsrv_init.patch
# Patch2: Fix Kolab bug 2229
Patch2:         fix-sasl-path.diff

BuildRequires:  bzip2
BuildRequires:  cyrus-sasl-devel >= 2.1.19
BuildRequires:  gcc-c++
BuildRequires:  krb5-devel
BuildRequires:  db-devel >= 4.5
# net-snmp-devel is needed to build the snmp ldap-agent
BuildRequires:  net-snmp-devel >= 5.1.2
BuildRequires:  openldap2-devel
# pam-devel is required the pam passthru auth plug-in
BuildRequires:  pam-devel
%if 0%{?sles_version}
BuildRequires:  libicu-devel >= 3.4
BuildRequires:  mozilla-nspr-devel >= 4.6.4
BuildRequires:  mozilla-nss-devel >= 3.11.4
BuildRequires:  pcre-devel
BuildRequires:  svrcore-devel >= 4.0.3
%else
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(nspr)
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(svrcore)
BuildRequires:  pkgconfig(systemd)
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Requires:       perl-Mozilla-LDAP

%if %{?with_systemd} == 0
# for the init script
Requires(post):   insserv
Requires(post):   /sbin/chkconfig
Requires(preun):  /sbin/chkconfig
Requires(preun):  /sbin/service
%else
# for systemd
%{?systemd_requires}
%endif
%if 0%{?suse_version}
Requires(post): fillup
%endif

Obsoletes:      389-ds < %{version}
Provides:       389-ds = %{version}

Recommends:     389-admin

%description
389 Directory Server is a full-featured LDAPv3 compliant server. In
addition to the standard LDAPv3 operations, it supports multi-master
replication, fully online configuration and administration, chaining,
virtual attributes, access control directives in the data, Virtual
List View, server-side sorting, SASL, TLS/SSL, and many other
features.


%package devel
Summary:        Development files for the 389 Directory Server
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}

%description devel
389 Directory Server is a full-featured LDAPv3 compliant server. In
addition to the standard LDAPv3 operations, it supports multi-master
replication, fully online configuration and administration, chaining,
virtual attributes, access control directives in the data, Virtual
List View, server-side sorting, SASL, TLS/SSL, and many other
features.

This package contains the development files for 389-ds.


%prep
%setup -q
%patch1 -p 0

%build
# openldap has no pkgconfig file; because of that, 389-ds will prefer
# mozldap. Force use of openldap.
%{configure} --enable-autobind \
             --with-openldap \
%if %{?with_systemd} == 1
             --with-systemdsystemunitdir \
             --with-systemdsystemconfdir \
             --with-systemdgroupname=dirsrv.target \
%else
             --with-initddir=%{_initddir} \
%endif
           ..
%{__make} %{?_smp_mflags};

%install
%{__make} install DESTDIR=%{buildroot};
find %{buildroot}/%{_libdir} -type f -name "*.la" -delete;

%if %{?with_systemd} == 1
# systemd directory used for instances created with setup
%{__install} -d %{buildroot}%{_unitdir}/dirsrv.target.wants
%endif

%if 0%{?suse_version}
mkdir -p %{buildroot}/%{_localstatedir}/adm/fillup-templates;
for i in %{buildroot}/%{_sysconfdir}/sysconfig/*; do
  mv $i %{buildroot}/%{_localstatedir}/adm/fillup-templates/sysconfig.${i##*/};
done;
%endif

%if %{?with_systemd} == 1
%pre
%service_add_pre dirsrv@*.service dirsrv-snmp.service dirsrv.target
%endif

%post
/sbin/ldconfig
%if %{?with_systemd} == 1
%if 0%{?suse_version}
%fillup_only -n dirsrv
%fillup_only -n dirsrv.systemd
%endif
%service_add_post dirsrv@*.service dirsrv-snmp.service dirsrv.target
%else
%fillup_and_insserv dirsrv
%endif

%preun
%if %{?with_systemd} == 1
%service_del_preun dirsrv@*.service dirsrv-snmp.service dirsrv.target
%else
%stop_on_removal dirsrv
%endif

%postun
/sbin/ldconfig
%if %{?with_systemd} == 1
%service_del_postun dirsrv@*.service dirsrv-snmp.service dirsrv.target
%else
%restart_on_update dirsrv
%insserv_cleanup
%endif

%files
%defattr(-,root,root)
%config %{_sysconfdir}/dirsrv
%{_bindir}/*
%dir %{_libdir}/dirsrv
%{_libdir}/dirsrv/*.so.*
%dir %{_libdir}/dirsrv/perl
%{_libdir}/dirsrv/perl/*.pm
%dir %{_libdir}/dirsrv/plugins
%{_libdir}/dirsrv/plugins/*.so
%{_sbindir}/*
%{_datadir}/dirsrv
%{_mandir}/man?/*
%if 0%{?suse_version}
%{_localstatedir}/adm/fillup-templates/sysconfig.*
%else
%{_sysconfdir}/sysconfig/*
%endif
%if %{?with_systemd} == 1
%{_unitdir}/dirsrv*
%else
%{_initddir}/*
%endif

%files devel
%defattr(-,root,root)
%{_includedir}/dirsrv
%{_libdir}/dirsrv/*.so
%{_libdir}/pkgconfig/dirsrv.pc

%changelog
* Wed Aug 20 2014 aj@ajaissle.de
- New upstream release 1.2.11.30
* Wed Aug 20 2014 aj@ajaissle.de
- Spec cleanup
* Wed May 14 2014 aj@ajaissle.de
- New upstream release 1.2.11.29
* Tue Jul 16 2013 aj@ajaissle.de
- Spec file improvements
- Add Suggests: 389-ds-console
- Requires: perl-Mozilla-LDAP
* Sun Mar 10 2013 aj@ajaissle.de
- Added systemd/system/dirsrv.target.wants
* Fri Mar  8 2013 aj@ajaissle.de
- Update to 1.2.11.15
- SLE 11 SP2 support
* Sat Dec 18 2010 nix@opensuse.org
- Update to 1.2.7.5
* Thu Nov 12 2009 nix@opensuse.org
- Initial rpm package for 389 DS
- Thanks to Rich Megginson for all his work on the Fedora spec
  Sat Dec 1 2007 Peter Nixon
- Modify spec to work on SUSE
- Add patch to allow db support to build on SUSE
* Tue Feb 13 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.1.20070213
- More cleanup suggested by Dennis Gilmore
- This is the fedora extras candidate based on cvs tag FedoraDirSvr110a1
* Fri Feb  9 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.el4.20070209
- latest sources
- added init scripts
- use /etc as instconfigdir
* Wed Feb  7 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.el4.20070207
- latest sources
- moved all executables to _bindir
* Mon Jan 29 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.el4.20070129
- latest sources
- added /var/tmp/fedora-ds to dirs
* Fri Jan 26 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-8.el4.20070125
- added logconv.pl
- added slapi-plugin.h to devel package
- added explicit dirs for /var/log/fedora-ds et. al.
* Thu Jan 25 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-7.el4.20070125
- just move all .so files into the base package from the devel package
* Thu Jan 25 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-6.el4.20070125
- Move the plugin *.so files into the main package instead of the devel
- package because they are loaded directly by name via dlopen
* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-5.el4.20070125
- Move the script-templates directory to datadir/fedora-ds
* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-4.el4.20070119
- change mozldap to mozldap6
* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-3.el4.20070119
- remove . from cvsdate define
* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-2.el4.20070119
- Having a problem building in Brew - may be Release format
* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.el4.cvs20070119
- Changed version to 1.1.0 and added Release 1.el4.cvs20070119
- merged in changes from Fedora Extras candidate spec file
* Mon Jan 15 2007 Rich Megginson <rmeggins@redhat.com> - 1.1-0.1.cvs20070115
- Bump component versions (nspr, nss, svrcore, mozldap) to their latest
- remove unneeded patches
* Tue Jan  9 2007 Dennis Gilmore <dennis@ausil.us> - 1.1-0.1.cvs20070108
- update to a cvs snapshot
- fedorafy the spec
- create -devel subpackage
- apply a patch to use mozldap not mozldap6
- apply a patch to allow --prefix to work correctly
* Mon Dec  4 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-16
- Fixed the problem where the server would crash upon shutdown in dblayer
- due to a race condition among the database housekeeping threads
- Fix a problem with normalized absolute paths for db directories
* Tue Nov 28 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-15
- Touch all of the ldap/admin/src/scripts/*.in files so that they
- will be newer than their corresponding script template files, so
- that make will rebuild them.
* Mon Nov 27 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-14
- Chown new schema files when copying during instance creation
* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-13
- Configure will get ldapsdk_bindir from pkg-config, or $libdir/mozldap6
* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-12
- use eval to sed ./configure into ../configure
* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-11
- jump through hoops to be able to run ../configure
* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-10
- Need to make built dir in setup section
* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-9
- The template scripts needed to use @libdir@ instead of hardcoding
- /usr/lib
- Use make DESTDIR=$RPM_BUILD_ROOT install instead of %% makeinstall
- do the actual build in a "built" subdirectory, until we remove
- the old script templates
* Thu Nov 16 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-8
- Make replication plugin link with libdb
* Wed Nov 15 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-7
- Have make define LIBDIR, BINDIR, etc. for C code to use
- especially for create_instance.h
* Tue Nov 14 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-6
- Forgot to checkin new config.h.in for AC_CONFIG_HEADERS
* Tue Nov 14 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-5
- Add perldap as a Requires; update sources
* Thu Nov  9 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-4
- Fix ds_newinst.pl
- Remove obsolete #defines
* Thu Nov  9 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-3
- Update sources; rebuild to populate brew yum repo with dirsec-nss
* Tue Nov  7 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-2
- Update sources
* Thu Nov  2 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-1
- initial revision
